aboutsummaryrefslogtreecommitdiff
path: root/src/main
diff options
context:
space:
mode:
Diffstat (limited to 'src/main')
-rw-r--r--src/main/patcher.ts15
1 files changed, 11 insertions, 4 deletions
diff --git a/src/main/patcher.ts b/src/main/patcher.ts
index c45a299..f92a64d 100644
--- a/src/main/patcher.ts
+++ b/src/main/patcher.ts
@@ -106,10 +106,17 @@ if (!IS_VANILLA) {
BrowserWindow
};
- // Patch appSettings to force enable devtools
- onceDefined(global, "appSettings", s =>
- s.set("DANGEROUS_ENABLE_DEVTOOLS_ONLY_ENABLE_IF_YOU_KNOW_WHAT_YOURE_DOING", true)
- );
+ // Patch appSettings to force enable devtools and optionally disable min size
+ onceDefined(global, "appSettings", s => {
+ s.set("DANGEROUS_ENABLE_DEVTOOLS_ONLY_ENABLE_IF_YOU_KNOW_WHAT_YOURE_DOING", true);
+ if (settings.disableMinSize) {
+ s.set("MIN_WIDTH", 0);
+ s.set("MIN_HEIGHT", 0);
+ } else {
+ s.set("MIN_WIDTH", 940);
+ s.set("MIN_HEIGHT", 500);
+ }
+ });
process.env.DATA_DIR = join(app.getPath("userData"), "..", "Vencord");
} else {